summaryrefslogtreecommitdiffstats
path: root/crawl-ref
diff options
context:
space:
mode:
authordolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2007-12-06 04:11:15 +0000
committerdolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2007-12-06 04:11:15 +0000
commit7640ea1ef75cecb46066e956ec446038c884643c (patch)
treebced7b2444fe0e5577700ac6056ce7a9f363f1af /crawl-ref
parentcb77f31c6f27c524b99287a9a07445601cb883bd (diff)
downloadcrawl-ref-7640ea1ef75cecb46066e956ec446038c884643c.tar.gz
crawl-ref-7640ea1ef75cecb46066e956ec446038c884643c.zip
Reenable the poisoned brand for javelins, as it apparently does work,
just as it does with thrown poisoned darts (oops). git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@3008 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref')
-rw-r--r--crawl-ref/source/makeitem.cc7
1 files changed, 5 insertions, 2 deletions
diff --git a/crawl-ref/source/makeitem.cc b/crawl-ref/source/makeitem.cc
index 7c1837cc9e..0d16328eb6 100644
--- a/crawl-ref/source/makeitem.cc
+++ b/crawl-ref/source/makeitem.cc
@@ -1699,9 +1699,12 @@ static special_missile_type determine_missile_brand(const item_def& item,
if (get_equip_race(item) == ISFLAG_ORCISH && one_chance_in(3))
rc = SPMSL_POISONED;
// Un-poison sling bullets; unbrand javelins and throwing nets.
if ((item.sub_type == MI_SLING_BULLET && rc == SPMSL_POISONED)
- || item.sub_type == MI_JAVELIN || item.sub_type == MI_THROWING_NET)
+ || (item.sub_type == MI_JAVELIN
+ && (rc == SPMSL_FLAME || rc == SPMSL_ICE))
+ || item.sub_type == MI_THROWING_NET)
{
rc = SPMSL_NORMAL;
}
@@ -1699,9 +1699,12 @@ static special_missile_type determine_missile_brand(const item_def& item,
if (get_equip_race(item) == ISFLAG_ORCISH && one_chance_in(3))
rc = SPMSL_POISONED;
- // Un-poison sling bullets; unbrand javelins and throwing nets.
+ // Un-poison sling bullets; un-flame and un-ice javelins; unbrand
+ // throwing nets.
if ((item.sub_type == MI_SLING_BULLET && rc == SPMSL_POISONED)